==> DI-engine-0.3.0.tar.gz: DI-engine-0.3.0/dizoo/classic_control/cartpole/config/cartpole_r2d2_residual_config.py <==
from easydict import EasyDict
import torch

collector_env_num = 8
evaluator_env_num = 5
cartpole_r2d2__residual_config = dict(
    exp_name='cartpole_r2d2_residual_link',
    env=dict(
        collector_env_num=collector_env_num,
        evaluator_env_num=evaluator_env_num,
        n_evaluator_episode=5,
        stop_value=195,
    ),
    policy=dict(
        cuda=False,
        priority=False,
        priority_IS_weight=False,
        model=dict(
            obs_shape=4,
            action_shape=2,
            encoder_hidden_size_list=[128, 128, 64],
            res_link=True,
        ),
        discount_factor=0.997,
        burnin_step=10,
        nstep=5,
        # (int) the whole sequence length to unroll the RNN network minus
        # the timesteps of burnin part,
        # i.e., <the whole sequence length> = <burnin_step> + <unroll_len>
        unroll_len=20,
        learn=dict(
            # according to the R2D2 paper, actor parameter update interval is 400
            # environment timesteps, and in per collect phase, we collect 32 sequence
            # samples, the length of each sample sequence is <burnin_step> + <unroll_len>,
            # which is 100 in our seeting, 32*100/400=8, so we set update_per_collect=8
            # in most environments
            update_per_collect=8,
            batch_size=64,
            learning_rate=0.0005,
            # according to the R2D2 paper, the target network update interval is 2500
            target_update_freq=2500,
        ),
        collect=dict(
            n_sample=32,
            env_num=collector_env_num,
        ),
        eval=dict(env_num=evaluator_env_num, evaluator=dict(eval_freq=20)),
        other=dict(
            eps=dict(
                type='exp',
                start=0.95,
                end=0.05,
                decay=10000,
            ), replay_buffer=dict(replay_buffer_size=100000, )
        ),
    ),
)
cartpole_r2d2__residual_config = EasyDict(cartpole_r2d2__residual_config)
main_config = cartpole_r2d2__residual_config
cartpole_r2d2_residual_create_config = dict(
    env=dict(
        type='cartpole',
        import_names=['dizoo.classic_control.cartpole.envs.cartpole_env'],
    ),
    env_manager=dict(type='base'),
    policy=dict(type='r2d2'),
)
cartpole_r2d2_residual_create_config = EasyDict(cartpole_r2d2_residual_create_config)
create_config = cartpole_r2d2_residual_create_config

if __name__ == "__main__":
    from ding.entry import serial_pipeline
    serial_pipeline([main_config, create_config], seed=0)

==> DI-engine-0.3.1.tar.gz: DI-engine-0.3.1/dizoo/classic_control/cartpole/config/cartpole_r2d2_residual_config.py <==
from easydict import EasyDict

collector_env_num = 8
evaluator_env_num = 5
cartpole_r2d2__residual_config = dict(
    exp_name='cartpole_r2d2_residual_seed0',
    env=dict(
        collector_env_num=collector_env_num,
        evaluator_env_num=evaluator_env_num,
        n_evaluator_episode=5,
        stop_value=195,
    ),
    policy=dict(
        cuda=False,
        priority=False,
        priority_IS_weight=False,
        model=dict(
            obs_shape=4,
            action_shape=2,
            encoder_hidden_size_list=[128, 128, 64],
            res_link=True,
        ),
        discount_factor=0.997,
        burnin_step=10,
        nstep=5,
        # (int) the whole sequence length to unroll the RNN network minus
        # the timesteps of burnin part,
        # i.e., <the whole sequence length> = <burnin_step> + <unroll_len>
        unroll_len=20,
        learn=dict(
            # according to the R2D2 paper, actor parameter update interval is 400
            # environment timesteps, and in per collect phase, we collect 32 sequence
            # samples, the length of each sample sequence is <burnin_step> + <unroll_len>,
            # which is 100 in our seeting, 32*100/400=8, so we set update_per_collect=8
            # in most environments
            update_per_collect=8,
            batch_size=64,
            learning_rate=0.0005,
            # according to the R2D2 paper, the target network update interval is 2500
            target_update_freq=2500,
        ),
        collect=dict(
            n_sample=32,
            env_num=collector_env_num,
        ),
        eval=dict(env_num=evaluator_env_num, evaluator=dict(eval_freq=20)),
        other=dict(
            eps=dict(
                type='exp',
                start=0.95,
                end=0.05,
                decay=10000,
            ), replay_buffer=dict(replay_buffer_size=100000, )
        ),
    ),
)
cartpole_r2d2__residual_config = EasyDict(cartpole_r2d2__residual_config)
main_config = cartpole_r2d2__residual_config
cartpole_r2d2_residual_create_config = dict(
    env=dict(
        type='cartpole',
        import_names=['dizoo.classic_control.cartpole.envs.cartpole_env'],
    ),
    env_manager=dict(type='base'),
    policy=dict(type='r2d2'),
)
cartpole_r2d2_residual_create_config = EasyDict(cartpole_r2d2_residual_create_config)
create_config = cartpole_r2d2_residual_create_config

if __name__ == "__main__":
    # or you can enter `ding -m serial -c cartpole_r2d2_residual_config.py -s 0`
    from ding.entry import serial_pipeline
    serial_pipeline((main_config, create_config), seed=0)
